histore.document package
========================

.. automodule:: histore.document
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 3

   histore.document.csv
   histore.document.json

Submodules
----------

.. toctree::
   :maxdepth: 3

   histore.document.base
   histore.document.df
   histore.document.external
   histore.document.mem
   histore.document.operator
   histore.document.reader
   histore.document.row
   histore.document.schema
   histore.document.sort
